@@ -98,7 +98,7 @@ fn read_vertex_indices(
     let count = mesh_object.vertex_index_count as usize;
     let offset = mesh_object.index_buffer_offset as u64;
     let mut reader = Cursor::new(mesh_index_buffer);
-    let indices = match mesh_object.draw_element_type {
+    match mesh_object.draw_element_type {
         DrawElementType::UnsignedShort => read_data::<_, u16, u32>(
             &mut reader,
             count,
@@ -111,9 +111,7 @@ fn read_vertex_indices(
             offset,
             std::mem::size_of::<u32>() as u64,
         ),
-    };
-
-    Ok(indices?)
+    }
 }
 
 fn read_attribute_data<T>(
@@ -246,12 +244,10 @@ pub fn read_texture_coordinates(
 }
 
 /// Returns all the colorset attributes for the specified `mesh_object`.
-/// Values are scaled from 0u8 to 255u8 to 0.0f32 to 1.0f32. If `divide_by_2` is `true`,
-/// the output range is 0.0f32 to 2.0f32.
+/// [u8] values are converted to [f32] by normalizing to the range 0.0 to 1.0.
 pub fn read_colorsets(
     mesh: &Mesh,
     mesh_object: &MeshObject,
-    divide_by_2: bool,
 ) -> Result<Vec<AttributeData>, Box<dyn Error>> {
     let colorsets = get_attributes(&mesh_object, AttributeUsage::ColorSet);
 
@@ -259,10 +255,9 @@ pub fn read_colorsets(
     for attribute in &colorsets {
         let mut data = read_attribute_data::<f32>(mesh, mesh_object, attribute)?;
 
-        // Normalize integral values by converting the range [0.0, 255.0] to [0.0, 2.0] or [0.0, 1.0].
-        // TODO: Make this optional?
+        // Normalize integral values by converting the range [0.0, 255.0] to [0.0, 1.0].
         // TODO: Find a cleaner/safer way to do this.
-        let divisor = if divide_by_2 { 128.0f32 } else { 255.0f32 };
+        let divisor = 255.0f32;
         match &mut data {
             VectorData::Vector2(v) => {
                 for element in v.iter_mut() {
@@ -363,7 +358,7 @@ pub fn read_mesh_objects(mesh: &Mesh) -> Result<Vec<MeshObjectData>, Box<dyn Err
         let tangents = read_attributes_by_usage(&mesh, &mesh_object, AttributeUsage::Tangent)?;
         let binormals = read_attributes_by_usage(&mesh, &mesh_object, AttributeUsage::Binormal)?;
         let texture_coordinates = read_texture_coordinates(&mesh, &mesh_object, true)?;
-        let color_sets = read_colorsets(&mesh, &mesh_object, true)?;
+        let color_sets = read_colorsets(&mesh, &mesh_object)?;
         let bone_influences =
             read_rigging_data(&mesh.rigging_buffers.elements, &name, mesh_object.sub_index)?;
 
@@ -396,17 +391,17 @@ pub fn update_mesh(
     mesh: &mut Mesh,
     updated_object_data: &[MeshObjectData],
 ) -> Result<(), Box<dyn Error>> {
-    let (mesh_objects, vertex_buffers, index_buffer) =
-        create_mesh_objects(mesh, updated_object_data)?;
+    let mesh_vertex_data = create_mesh_objects(mesh, updated_object_data)?;
 
-    mesh.objects.elements = mesh_objects;
+    mesh.objects.elements = mesh_vertex_data.mesh_objects;
 
-    mesh.vertex_buffers.elements = vertex_buffers
+    mesh.vertex_buffers.elements = mesh_vertex_data
+        .vertex_buffers
         .into_iter()
         .map(|b| SsbhByteBuffer { elements: b })
         .collect();
 
-    mesh.index_buffer.elements = index_buffer;
+    mesh.index_buffer.elements = mesh_vertex_data.index_buffer;
 
     mesh.rigging_buffers.elements = create_rigging_buffers(mesh, updated_object_data)?;
 
@@ -447,13 +442,22 @@ fn create_rigging_buffers(
         let buffer = MeshRiggingGroup {
             mesh_object_name: mesh_object.name.clone().into(),
             mesh_object_sub_index: mesh_object.sub_index,
-            flags: flags,
+            flags,
             buffers: buffers.into(),
         };
 
         rigging_buffers.push(buffer)
     }
 
+    // Rigging buffers need to be sorted in ascending order by name and sub_index. 
+    // TODO: Using a default may impact sorting if mesh_object_name is a null offset.
+    rigging_buffers.sort_by_key(|k| {
+        (
+            k.mesh_object_name.get_string().unwrap_or("").to_string(),
+            k.mesh_object_sub_index,
+        )
+    });
+
     Ok(rigging_buffers)
 }
 
@@ -759,11 +763,16 @@ fn create_attributes_v10(data: &MeshObjectData) -> (u32, u32, MeshAttributes) {
     )
 }
 
-// TODO: Use a struct for the return type?
+struct MeshVertexData {
+    mesh_objects: Vec<MeshObject>,
+    vertex_buffers: Vec<Vec<u8>>,
+    index_buffer: Vec<u8>,
+}
+
 fn create_mesh_objects(
     source_mesh: &Mesh,
     mesh_object_data: &[MeshObjectData],
-) -> Result<(Vec<MeshObject>, Vec<Vec<u8>>, Vec<u8>), Box<dyn Error>> {
+) -> Result<MeshVertexData, Box<dyn Error>> {
     // TODO: Split this into functions and do some cleanup.
     let mut mesh_objects = Vec::new();
 
@@ -905,16 +914,16 @@ fn create_mesh_objects(
 
     // There are always four vertex buffers, but only the first two contain data.
     // The remaining two vertex buffers are empty.
-    Ok((
+    Ok(MeshVertexData {
         mesh_objects,
-        vec![
+        vertex_buffers: vec![
             buffer0.into_inner(),
             buffer1.into_inner(),
             Vec::new(),
             Vec::new(),
         ],
-        index_buffer.into_inner(),
-    ))
+        index_buffer: index_buffer.into_inner(),
+    })
 }
 
 fn write_f32<W: Write>(writer: &mut W, data: &[f32]) -> Result<(), Box<dyn Error>> {
@@ -947,21 +956,6 @@ fn write_u8<W: Write>(writer: &mut W, data: &[f32]) -> Result<(), Box<dyn Error>
     Ok(())
 }
 
-fn write_all_u8<W: Write>(
-    writer: &mut W,
-    attributes: &[AttributeData],
-    index: usize,
-) -> Result<(), Box<dyn Error>> {
-    for attribute in attributes {
-        match &attribute.data {
-            VectorData::Vector2(v) => write_u8(writer, &v[index])?,
-            VectorData::Vector3(v) => write_u8(writer, &v[index])?,
-            VectorData::Vector4(v) => write_u8(writer, &v[index])?,
-        }
-    }
-    Ok(())
-}
-
 fn write_f16<W: Write>(writer: &mut W, data: &[f32]) -> Result<(), Box<dyn Error>> {
     for component in data {
         writer.write_all(&f16::from_f32(*component).to_le_bytes())?;
@@ -1084,13 +1078,7 @@ fn get_u8_clamped(f: f32) -> u8 {
 /// Gets the name of the mesh attribute. This uses the attribute names array,
 /// which can be assumed to contain a single value that is unique with respect to the other attributes for the mesh object.
 pub fn get_attribute_name(attribute: &MeshAttributeV10) -> Option<&str> {
-    attribute
-        .attribute_names
-        .elements
-        .iter()
-        .next()
-        .unwrap()
-        .get_string()
+    attribute.attribute_names.elements.get(0)?.get_string()
 }
 
 #[cfg(test)]
